@@ -37,7 +37,7 @@
 
 class KDE_EXPORT VPNConfigWidget : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		virtual ~VPNConfigWidget();
@@ -53,7 +53,7 @@ class KDE_EXPORT VPNConfigWidget : public TQWidget
 
 class KDE_EXPORT VPNAuthenticationWidget : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		virtual ~VPNAuthenticationWidget();
@@ -67,7 +67,7 @@ class KDE_EXPORT VPNAuthenticationWidget : public TQWidget
 
 class KDE_EXPORT VPNPlugin : public Plugin
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		VPNPlugin(TQObject*, const char*, const TQStringList&);
